@---------------------------------------------------------------------

For Table 2 of article "Do Changes in Reserves Proxy Well for Official 
Intervention?" by Christopher J. Neely in September/October 2000 issue 
of the Federal Reserve Bank of St. Louis Review. 

---------------------------------------------------------------------@


/*---------------------- Corrlate.PRG -----------------------------------*/
/*  This prgs produces correlation coefficients for monthly changes
in reserves and cumulated monthly CBI */
/*-----------------------------------------------------------------------*/
new;
library pgraph;
#include reserves.lib;
graphset;

inname0 = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\cbires";
grfname1 = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\UScorr.grf";
outname = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\corr.tab";
datname = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\corr.dat";
outdata = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\corrroll.dat";

/*--------------------------------------------------------------------*/
/*  Variables in "cbires" are YYMM fedcbi1 fedcbi2 USIntRes USFXRes ausintres
ausfxres */
/*--------------------------------------------------------------------*/

open f1 = ^inname0;
y = readr(f1,rowsf(f1));
yymm = y[.,1];
datz = 1900 + trunc(yymm/100) + (yymm - 100*trunc(yymm/100))/12;

outcorr = miss(0~0~0~0,0);
length = 48;
corrdata = miss(zeros(rows(datz)-(length-1),3),0);


/*---------------------------------------------------------------*/
/*-------------------------- US DATA ----------------------------*/
/*---------------------------------------------------------------*/
header = "CBI in M"|"CBI Both"|"DIntRes"|"DFXRes";
datset = y[.,1|2|3|4|5];

{corrij,dates,strmat} = rollcorr(header,datset,length);
outcorr = outcorr|dates|strmat|miss(0~0~0~0,0);
i1 = 2;         @ First variable--index in header--in rolling corr @
i2 = 4;         @ second variable--index in header--in rolling corr @
x = xpnd(seqa(1,1,15));
indx = x[i1,i2-1];
corrdata[.,1] = corrij[.,indx];

graphset;
_pnum = {1 , 2};
_pcolor = 8;  _pmcolor = 8;  _pltype = 6;
_pnumht = .3;  _paxht = .3;  _ptitlht = .4;  _pframe = 0;  _pdate = 0;
xtics(1978,1999,8,2);
begwind;
window(cols(corrij),1,1);
setwind(1);
w = 1;
do while w <= cols(corrij);

if w > 1; nextwind; endif;

tstr = ftos(length,"%*.*lf",1,0) $+ "-Month Moving Average of \L";
title(tstr $+ "Corr(" $+ strmat[w,1] $+ "," $+ strmat[w,2] $+ ")");
xy(datz[length:rows(datz),1],corrij[.,w]);
w = w + 1;
endo;

cmdstr = " -c=3 -cf=" $+ grfname1 $+ " -w=2";
graphprt(cmdstr);
endwind;

/*

/*---------------------------------------------------------------*/
/*----------------------- German DATA ----------------------------*/
/*---------------------------------------------------------------*/
header = "CBI"|"DIntRes"|"DFXRes";
datset = y[.,1|4|10|11];

{corrij,dates,strmat} = rollcorr(header,datset,length);
outcorr = outcorr|dates|strmat|miss(0~0~0~0,0);
i1 = 1;         @ First variable--index in header--in rolling corr @
i2 = 3;         @ second variable--index in header--in rolling corr @
x = xpnd(seqa(1,1,15));
indx = x[i1,i2-1];
corrdata[.,2] = corrij[.,indx];

graphset;
_pnum = {1 , 2};
_pcolor = 8;  _pmcolor = 8;  _pltype = 6;
_pnumht = .3;  _paxht = .3;  _ptitlht = .4;  _pframe = 0;  _pdate = 0;
xtics(1978,1999,8,2);
begwind;
window(cols(corrij),1,1);
setwind(1);


w = 1;
do while w <= cols(corrij);

if w > 1; nextwind; endif;

tstr = ftos(length,"%*.*lf",1,0) $+ "-Month Moving Average of \L";
title(tstr $+ "Corr(" $+ strmat[w,1] $+ "," $+ strmat[w,2] $+ ")");
xy(datz[length:rows(datz),1],corrij[.,w]);
w = w + 1;
endo;


cmdstr = " -c=3 -cf=" $+ grfname2 $+ " -w=2";
graphprt(cmdstr);
endwind;

/*---------------------------------------------------------------*/
/*----------------------- Swiss DATA ----------------------------*/
/*---------------------------------------------------------------*/
header = "CBI 1"|"CBI 2"|"CBI 3"|"DIntRes"|"DFXRes";
datset = y[.,1|5|6|7|12|13];

{corrij,dates,strmat} = rollcorr(header,datset,length);
outcorr = outcorr|dates|strmat|miss(0~0~0~0,0);
i1 = 2;         @ First variable--index in header--in rolling corr @
i2 = 5;         @ second variable--index in header--in rolling corr @
x = xpnd(seqa(1,1,15));
indx = x[i1,i2-1];
corrdata[.,3] = corrij[.,indx];


/*-------------------- Graph -----------------------------------*/
graphset;
_pnum = {1 , 2};
_pcolor = 8;  _pmcolor = 8;  _pltype = 6;
_pnumht = .3;  _paxht = .3;  _ptitlht = .4;  _pframe = 0;  _pdate = 0;
xtics(1978,1999,8,2);
begwind;
window(cols(corrij),1,1);
setwind(1);
w = 1;
do while w <= cols(corrij);

if w > 1; nextwind; endif;

tstr = ftos(length,"%*.*lf",1,0) $+ "-Month Moving Average of \L";
title(tstr $+ "Corr(" $+ strmat[w,1] $+ "," $+ strmat[w,2] $+ ")");
xy(datz[length:rows(datz),1],corrij[.,w]);
w = w + 1;
endo;

cmdstr = " -c=3 -cf=" $+ grfname3 $+ " -w=2";
graphprt(cmdstr);
endwind;


/*---------- Graph interventions with correlations ---------------*/
 graphset;
_pnum = {1 , 2};
_pcolor = 8;  _pmcolor = 8;  _pltype = 1|5|6;
_pnumht = .2;  _paxht = .2;  _ptitlht = .2;
_pframe = 0;  _pdate = 0;

scale(datz[length:rows(datz),.],corrdata);
xtics(1978,1999,1,2);
begwind;
makewind(8.5,11,0,0,1);
makewind(8.5,11,0,0,1);
makewind(8.5,11,0,0,1);
setwind(1);
w = 1;
do while w <= cols(corrdata);

if w > 1; nextwind; endif;

if w == 1;
_pltype = 1; _plegctl = 2|4|6.5|1;  _plegstr = " U.S.      ";
elseif w == 2;
_pltype = 3; _plegctl = 2|4|6.5|1.45;  _plegstr = "Germany  ";
_plwidth = 8;
elseif w == 3;
_pltype = 6; _plegctl = 2|4|6.5|1.9;  _plegstr = "Switzerland";
_plwidth = 0;
endif;

m = packr(datz[length:rows(datz),1]~corrdata[1:rows(corrdata),w]);
xy(m[.,1],m[.,2]);
w = w + 1;
endo;

cmdstr = " -c=3 -cf=" $+ grfname4 $+ " -w=2";
graphprt(cmdstr);
endwind;


*/

let vnames = DATES US48;
z = saved(datz[length:rows(datz),1]~corrdata,outdata,vnames);
z;


/*---------------------- Output from all 3 cases --------------------*/
output file = ^outname reset;
$outcorr;
output off;

let vnames = Var1 Var2 Corr CorrSE;
z = saved(stof(outcorr),datname,vnames);
z;


