@---------------------------------------------------------------------

For Figure 2 of article "Do Changes in Reserves Proxy Well for 
Official Intervention?" by Christopher J. Neely in September/October 
2000 issue of the Federal Reserve Bank of St. Louis Review. 

---------------------------------------------------------------------@

/*---------------------- Figure2.PRG -----------------------------------*/
/*  This prgs produces correlation coefficients for monthly changes
in reserves and cumulated monthly CBI.  It then graphs selected correlations
for the inclusive CBI measure and changes in monthly FX reserves.  */
/*-----------------------------------------------------------------------*/
new;
library pgraph;
#include reserves.lib;
graphset;

inname0 = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\cbires";
grfname1 = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\figure2.eps";
grfname2 = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\fig2info.grf";

/*--------------------------------------------------------------------*/
/*  Variables in "cbires" are YYMM fedcbi1 fedcbi2 USIntRes USFXRes
        USIntRes USFXRes  */
/*--------------------------------------------------------------------*/

open f1 = ^inname0;
y = readr(f1,rowsf(f1));
yymm = y[.,1];
length = 48;
datz = 1900 + trunc(yymm/100) + ((yymm - 100*trunc(yymm/100))-1)/12;
corrdata = miss(zeros(rows(datz)-(length-1),3),0);
corrdatz = yymm[seqa(length,1,rows(corrdata)),1];

/*---------------------------------------------------------------*/
/*-------------------------- US DATA ----------------------------*/
/*---------------------------------------------------------------*/
header = "CBI in M"|"CBI Both"|"DIntRes"|"DFXRes";
datset = y[.,1|2|3|4|5];

{corrij,dates,strmat} = rollcorr(header,datset,length);
i1 = 2;         @ First variable--index in header--in rolling corr @
i2 = 4;         @ second variable--index in header--in rolling corr @
x = xpnd(seqa(1,1,15));
indx = x[i1,i2-1];
corrdata[.,1] = corrij[.,indx];


/*-------------------- Graph the data --------------------------*/
datevec = miss(0~0,0);

 graphset;
_pnum = {1 , 2};
_pcolor = 8;  _pmcolor = 8;  _pltype = 1|5|6;
_pnumht = .2;  _paxht = .2;  _ptitlht = .2;
_pframe = 0;  _pdate = 0;
_plegstr = "U.S.";
_plegctl = 2|4|6.5|1;


scale(datz[length:rows(datz),.],corrdata);
xtics(1976,1999,4,1);
begwind;
makewind(8.5,11,0,0,1);
makewind(8.5,11,0,0,1);
makewind(8.5,11,0,0,1);
setwind(1);

_pltype = 1; _plegctl = 2|4|6.5|1;  _plegstr = " U.S.      ";

m = packr(datz[length:rows(datz),1]~corrdata[1:rows(corrdata),1]);

datevec = datevec|minc(m[.,1])~maxc(m[.,1]);

xy(m[.,1],m[.,2]);

cmdstr = " -c=1 -cf=" $+ grfname1 $+ " -w=2";
graphprt(cmdstr);
endwind;

@datevec; wait;@


/*---------- Graph interventions with correlations ---------------*/
 graphset;
_pnum = {1 , 2};
_pcolor = 8;  _pmcolor = 8;  _pltype = 1|5|6;
_pnumht = .3;  _paxht = .3; @ _ptitlht = .2;@
_pframe = 0;  _pdate = 0;

indx = miss(0,0)|3|4|6;

xtics(1976,1999,4,1);
begwind;
makewind(8.5,11,0,0,1);
makewind(8.5,11,0,0,1);
makewind(8.5,11,0,0,1);

setwind(1);

m = datz[length:rows(datz),1]~y[length:rows(y),indx[2]];
xy(m[.,1],m[.,2]);

cmdstr = " -c=3 -cf=" $+ grfname2 $+ " -w=5";
graphprt(cmdstr);
endwind;


