@---------------------------------------------------------------------

For Table 2 of article "Do Changes in Reserves Proxy Well for Official 
Intervention?" by Christopher J. Neely in September/October 2000 issue 
of the Federal Reserve Bank of St. Louis Review. 

---------------------------------------------------------------------@

/*---------------------- EMScor2.PRG -----------------------------------*/
/*  This prgs produces correlation coefficients for monthly changes
in reserves and cumulated monthly CBI.  It then graphs selected correlations
for the inclusive CBI measure and changes in monthly FX reserves.

This prg removes months of EMS realignments for the DM, IL, DG and GBP.

THIS PRG DOES CORRELATIONS ON THE RESERVES DATA AFTER ADJUSTMENTS
FOR INTEREST INCOME. */
/*-----------------------------------------------------------------------*/
new;
library pgraph;
#include reserves.lib;
graphset;

inname0 = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\cbires";
outname = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\emscor2.tab";
datname = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\emscor2.dat";
grfname1 = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\fig2em2.grf";
grfname2 = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\fig2ein2.grf";
outdata = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\emsrol2.dat";
outcorr = miss(0~0~0~0,0);

/*---------------- Read in realignment months -----------------------*/
load rm[] = n:\cjn\review\reserves\draft3\step6\fred\emsdates.out;

/*--------------------------------------------------------------------*/
/*  Variables in "cbires" are YYMM fedcbi1 fedcbi2 
    USIntRes USFXRes aUSIntRes aUSFXRes  */
/*--------------------------------------------------------------------*/

open f1 = ^inname0;
y = readr(f1,rowsf(f1));

/*----------------------- Delete Realignment Periods ----------*/
y = delif(y,sumc((y[.,1] .== rm')') .== ones(rows(y),1));

yymm = y[.,1];
length = 48;
datz = 1900 + trunc(yymm/100) + (yymm - 100*trunc(yymm/100))/12;
corrdata = miss(zeros(rows(datz)-(length-1),3),0);

/*---------------------------------------------------------------*/
/*-------------------------- US DATA ----------------------------*/
/*---------------------------------------------------------------*/
header = "CBI in M"|"CBI Both"|"DIntRes"|"DFXRes";
datset = y[.,1|2|3|6|7];

{corrij,dates,strmat} = rollcorr(header,datset,length);
outcorr = outcorr|dates|strmat|miss(0~0~0~0,0);
i1 = 2;         @ First variable--index in header--in rolling corr @
i2 = 4;         @ second variable--index in header--in rolling corr @
x = xpnd(seqa(1,1,15));
indx = x[i1,i2-1];
corrdata[.,1] = corrij[.,indx];


/*- ---------------- Graph -----------------------------*/
 graphset;
_pnum = {1 , 2};
_pcolor = 8;  _pmcolor = 8;  _pltype = 1|5|6;
_pnumht = .2;  _paxht = .2;  _ptitlht = .2;
_pframe = 0;  _pdate = 0;
_plegstr = "U.S. ";
_plegctl = 2|4|6.5|1;

@_plegctl = 1;@


scale(datz[length:rows(datz),.],corrdata);
xtics(1978,1999,1,2);
begwind;
makewind(8.5,11,0,0,1);
makewind(8.5,11,0,0,1);
makewind(8.5,11,0,0,1);
setwind(1);

_pltype = 1; _plegctl = 2|4|6.5|1;  _plegstr = " U.S.      ";

m = packr(datz[length:rows(datz),1]~corrdata[1:rows(corrdata),1]);
xy(m[.,1],m[.,2]);


cmdstr = " -c=3 -cf=" $+ grfname1 $+ " -w=2";
graphprt(cmdstr);
endwind;


/*---------- Graph interventions with correlations ---------------*/
 graphset;
_pnum = {1 , 2};
_pcolor = 8;  _pmcolor = 8;  _pltype = 1|5|6;
_pnumht = .3;  _paxht = .3; @ _ptitlht = .2;@
_pframe = 0;  _pdate = 0;

indx = miss(0,0)|3|4|6;

xtics(1978,1999,2,2);
begwind;
makewind(8.5,11,0,0,1);
makewind(8.5,11,0,0,1);
makewind(8.5,11,0,0,1);

setwind(1);

m = datz[length:rows(datz),1]~y[length:rows(y),indx[2]];
xy(m[.,1],m[.,2]);

cmdstr = " -c=3 -cf=" $+ grfname2 $+ " -w=5";
graphprt(cmdstr);
endwind;

/*---------------------- Output from all 3 cases --------------------*/
output file = ^outname reset;
$outcorr;
output off;

let vnames = Var1 Var2 Corr CorrSE;
z = saved(stof(outcorr),datname,vnames);
z;

let vnames = DATES US48;
z = saved(datz[length:rows(datz),1]~corrdata,outdata,vnames);
z;

