@---------------------------------------------------------------------

For Table 2 of article "Do Changes in Reserves Proxy Well for 
Official Intervention?" by Christopher J. Neely in September/October 
2000 issue of the Federal Reserve Bank of St. Louis Review. 

---------------------------------------------------------------------@

/*---------------------- Seascor2.PRG -----------------------------------*/
/*  This prgs produces correlation coefficients for monthly changes
in reserves and cumulated monthly CBI.  It then graphs selected correlations
for the inclusive CBI measure and changes in monthly FX reserves.

This prg deseasonalizes reserve changes before calculating correlations
and graphing the correlations.

THIS PRG DOES CORRELATIONS ON THE RESERVES DATA AFTER ADJUSTMENTS
FOR INTEREST INCOME. */
/*-----------------------------------------------------------------------*/
new;
library pgraph;
#include reserves.lib;
graphset;

inname0 = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\cbires";
outname1 = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\seascor2.tab";
datname1 = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\seascor2.dat";
outname2 = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\seaspar2.tab";
datname2 = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\seaspar2.dat";
olsname = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\seasinf2.out";
grfname1 = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\fig2sea2.grf";
grfname2 = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\fig2sin2.grf";
outdata = "n:\\cjn\\review\\reserves\\draft3\\step6\\fred\\seasrol2.dat";
outcorr = miss(0~0~0~0,0);

/*--------------------------------------------------------------------*/
/*  Variables in "cbires" are YYMM fedcbi1 fedcbi2 
	USIntRes USFXRes USIntRes USFXRes  */
/*--------------------------------------------------------------------*/
open f1 = ^inname0;
y = readr(f1,rowsf(f1));

yymm = y[.,1];
length = 48;
datz = 1900 + trunc(yymm/100) + (yymm - 100*trunc(yymm/100))/12;
corrdata = miss(zeros(rows(datz)-(length-1),3),0);


/*------------------- Deseasonalize the reserves data -----------------*/
dumset = (yymm - 100*trunc(yymm/100)) .== seqa(1,1,12)';

errs = miss(zeros(rows(y),6),0);
bhatse = miss(zeros(12,4),0);
twodates = miss(zeros(2,3),0);
output file = ^olsname reset;
i = 6;
do while i <= 7;
__con = 0;  _olsres = 1;  __miss = 1;  __output = 1;
indx = packr(seqa(1,1,rows(y))~y[.,i]);
{vnam,m,b1,stb,vc1,stderr,sig,cx,rsq,e1,dw} = ols(0,y[.,i],dumset);
errs[indx[.,1],i-5] = e1;
bhatse[.,2*(i-6)+1:2*(i-6)+2] = b1~sqrt(diag(vc1));
temp = packr(y[.,1|i]);
twodates[i-5,.] = minc(temp[.,1])~maxc(temp[.,1])~rows(temp);
i = i + 1;
endo;

"";
" beginning and ending dates and Obs ";
twodates;
output off;

y[.,6:7] = errs[.,1:2];      @ Replace data with deseasonalized data @


/*---------------------------------------------------------------*/
/*-------------------------- US DATA ----------------------------*/
/*---------------------------------------------------------------*/
header = "CBI in M"|"CBI Both"|"DIntRes"|"DFXRes";
datset = y[.,1|2|3|6|7];

{corrij,dates,strmat} = rollcorr(header,datset,length);
outcorr = outcorr|dates|strmat|miss(0~0~0~0,0);
i1 = 2;         @ First variable--index in header--in rolling corr @
i2 = 4;         @ second variable--index in header--in rolling corr @
x = xpnd(seqa(1,1,15));
indx = x[i1,i2-1];
corrdata[.,1] = corrij[.,indx];


/*-------------------------- Graph -----------------------------*/

 graphset;
_pnum = {1 , 2};
_pcolor = 8;  _pmcolor = 8;  _pltype = 1|5|6;
_pnumht = .2;  _paxht = .2;  _ptitlht = .2;
_pframe = 0;  _pdate = 0;
_plegstr = "U.S.";
_plegctl = 2|4|6.5|1;

@_plegctl = 1;@


scale(datz[length:rows(datz),.],corrdata);
xtics(1976,1999,4,2);
begwind;
makewind(8.5,11,0,0,1);
makewind(8.5,11,0,0,1);
makewind(8.5,11,0,0,1);
setwind(1);

_pltype = 1; _plegctl = 2|4|6.5|1;  _plegstr = " U.S.      ";

m = packr(datz[length:rows(datz),1]~corrdata[1:rows(corrdata),1]);
xy(m[.,1],m[.,2]);

cmdstr = " -c=3 -cf=" $+ grfname1 $+ " -w=2";
graphprt(cmdstr);
endwind;


/*---------- Graph interventions with correlations ---------------*/
 graphset;
_pnum = {1 , 2};
_pcolor = 8;  _pmcolor = 8;  _pltype = 1|5|6;
_pnumht = .3;  _paxht = .3; @ _ptitlht = .2;@
_pframe = 0;  _pdate = 0;

indx = miss(0,0)|3|4|6;

xtics(1976,1999,4,2);
begwind;
makewind(8.5,11,0,0,1);
makewind(8.5,11,0,0,1);
makewind(8.5,11,0,0,1);

setwind(1);

m = datz[length:rows(datz),1]~y[length:rows(y),indx[2]];
xy(m[.,1],m[.,2]);

cmdstr = " -c=3 -cf=" $+ grfname2 $+ " -w=5";
graphprt(cmdstr);
endwind;


/*---------------------- Output from all 3 cases --------------------*/
output file = ^outname1 reset;
$outcorr;
output off;

outwidth 256;
format /rd 7,1;
output file = ^outname2 reset;
bhatse;
output off;


let vnames1 = Var1 Var2 Corr CorrSE;
z = saved(stof(outcorr),datname1,vnames1);
z;

let vnames2 = Bus1 SEus1 Bus2 SEus2;
z = saved(bhatse,datname2,vnames2);
z;


let vnames = DATES US48;
z = saved(datz[length:rows(datz),1]~corrdata,outdata,vnames);
z;

